"""PyInstaller runtime hook for setuptools entry points.

Monkey patches `pkg_resources.iter_entry_points` to return all entry
points as saved by `entrypoints.dump_entry_points` in the PyInstaller
spec file.

"""
import functools
import json
import os
import pkg_resources
import sys


class Distribution(object):
    """Fake setuptools distribution."""
    def __init__(self, key):
        self.key = key

    def requires(self, *unused_args, **unused_kwargs):
        return []

def patch(mod):
    """Monkey patch module's attributes."""
    def wrapper(f):   # pylint: disable=missing-docstring
        old = getattr(mod, f.__name__, f)
        def wrapper2(*args, **kwargs):  # pylint: disable=missing-docstring
            return f(old, *args, **kwargs)
        setattr(mod, f.__name__, wrapper2)
        return wrapper2
    return wrapper

def iter_entry_points_factory(all_entry_points):
    """Make patchable ``iter_entry_points`` that uses ``all_entry_points``."""
    def iter_entry_points(old_iter_entry_points, group, *args, **kwargs):
        """Monkey patched ``iter_entry_points``."""
        if group in all_entry_points:
            for dist_name, entry_points in all_entry_points[group].iteritems():
                dist = Distribution(dist_name)
                return [pkg_resources.EntryPoint.parse(entry_point, dist=dist)
                        for entry_point in entry_points]
        else:
            return old_iter_entry_points(group, *args, **kwargs)
    return iter_entry_points

def main():
    """Monkey-patch `pkg_resources` with correct database."""
    entry_points_path = os.path.join(sys._MEIPASS, 'entry_points.json')
    with open(entry_points_path) as fp:
        all_entry_points = json.loads(fp.read())
    patch(pkg_resources)(iter_entry_points_factory(all_entry_points))


if __name__ == '__main__':
    main()  # pragma: no cover



import codecs
import os
import sys
import setuptools


here = os.path.abspath(os.path.dirname(__file__))
readme = codecs.open(os.path.join(here, 'README.rst'), encoding='utf-8').read()

install_requires = [
    'acme>=0.17,<0.18',
    'cryptography',
    'pyOpenSSL',
    'pytz',
    'requests',
]

if sys.version_info < (2, 7):
    install_requires.extend([
        'argparse',
        'mock<1.1.0',
    ])
else:
    install_requires.extend([
        'mock',
    ])

tests_require = [
    'pep8',
    'pylint',
]

setuptools.setup(
    name='simp_le-client',
    author='Ian Denhardt',
    author_email='ian@zenhack.net',
    description="Simple Let's Encrypt Client",
    long_description=readme,
    license='GPLv3',
    url='https://github.com/zenhack/simp_le',
    py_modules=['simp_le'],
    setup_requires=['setuptools_scm'],
    use_scm_version=True,
    install_requires=install_requires,
    extras_require={
        'tests': tests_require,
    },
    entry_points={
        'console_scripts': [
            'simp_le = simp_le:main',
        ],
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Security',
        'Topic :: System :: Installation/Setup',
        'Topic :: System :: Networking',
        'Topic :: System :: Systems Administration',
        'Topic :: Utilities',
    ],
)
